@@ -14,18 +14,17 @@ VonMisesParameter <- function (azimuths)
   n_elements = length(azimuths)
   mean_module = (MeanModule(azimuths))
   if (mean_module < 0.53) {
-    parameter = (2 * mean_module) + (mean_module^3) + (5 * 
-      (mean_module^5)/6)
+    parameter = (2 * mean_module) + (mean_module^3) + (5 * (mean_module^5)/6)
   }
-  if ((mean_module >= 0.53) & (mean_module < 0.85)) {
-    parameter = -0.4 + (1.39 * mean_module) + (0.43/(1 - 
-      mean_module))
+  else{
+	if ((mean_module >= 0.53) & (mean_module < 0.85)) {
+		parameter = -0.4 + (1.39 * mean_module) + (0.43/(1 - mean_module))
+	}
+	else{
+		# if (mean_module >= 0.85)
+		parameter = 1/((mean_module^3) - (4 * mean_module^2) + 3 * mean_module)
+	}
   }
-  if (mean_module >= 0.85) {
-    parameter = 1/((mean_module^3) - (4 * mean_module^2) + 
-      3 * mean_module)
-  }
-
   # correction for small samples 
 
   if (n_elements < 16) {
